@@ -47,12 +47,7 @@ class FooterKey(Widget):
         }
 
         &.-disabled {
-            text-style: dim;
-            &:hover {
-                .footer-key--key {
-                    background: $foreground-disabled;
-                }
-            }
+            text-style: dim;            
         }
 
         &.-compact {
@@ -207,9 +202,10 @@ class Footer(ScrollableContainer, can_focus=False, can_focus_children=False):
     def compose(self) -> ComposeResult:
         if not self._bindings_ready:
             return
+        active_bindings = self.screen.active_bindings
         bindings = [
             (binding, enabled, tooltip)
-            for (_, binding, enabled, tooltip) in self.screen.active_bindings.values()
+            for (_, binding, enabled, tooltip) in active_bindings.values()
             if binding.show
         ]
         action_to_bindings: defaultdict[str, list[tuple[Binding, bool, str]]]
@@ -229,20 +225,22 @@ class Footer(ScrollableContainer, can_focus=False, can_focus_children=False):
                 tooltip=tooltip,
             ).data_bind(Footer.compact)
         if self.show_command_palette and self.app.ENABLE_COMMAND_PALETTE:
-            for key, binding in self.app._bindings:
-                if binding.action in (
-                    "app.command_palette",
-                    "command_palette",
-                ):
-                    yield FooterKey(
-                        key,
-                        self.app.get_key_display(binding),
-                        binding.description,
-                        binding.action,
-                        classes="-command-palette",
-                        tooltip=binding.tooltip or binding.description,
-                    )
-                    break
+            try:
+                _node, binding, enabled, tooltip = active_bindings[
+                    self.app.COMMAND_PALETTE_BINDING
+                ]
+            except KeyError:
+                pass
+            else:
+                yield FooterKey(
+                    binding.key,
+                    self.app.get_key_display(binding),
+                    binding.description,
+                    binding.action,
+                    classes="-command-palette",
+                    disabled=not enabled,
+                    tooltip=binding.tooltip or binding.description,
+                )
 
     async def bindings_changed(self, screen: Screen) -> None:
         self._bindings_ready = True
